@@ -18,7 +18,7 @@ class Component(Extendable, ABC):
         self._container = container
 
         self._outer_frame = Frame(self._container)
-        self._frame = None  # Add child elements to this frame in _render()
+        self._frame = None  # Add child elements to this frame in ._render()
 
         # Allow the outer frame to expand to fill the container
         self._outer_frame.rowconfigure(0, weight=1)
@@ -119,7 +119,9 @@ class Component(Extendable, ABC):
 
     def render(self) -> Frame:
         """
-        This method should be invoked externally, and the returned frame have pack() or grid() called on it
+        This method should be invoked externally, and the returned frame have pack() or grid() called on it.
+        It will always be called at least once, when setting up/populating the parent widget, but can be
+        called again if its child widgets need to be refreshed entirely
         """
 
         for child_element in self._outer_frame.winfo_children():
@@ -133,6 +135,20 @@ class Component(Extendable, ABC):
 
         return self._outer_frame
 
+    def update(self) -> None:
+        """
+        This method should be invoked externally if necessary,
+        In situations where ._update() needs to be carried out immediately rather than at the next interval
+        """
+
+        if not self.exists:
+            return
+
+        self._update()
+
+        if self._needs_render:
+            self.render()
+
     def _update_loop(self) -> None:
         """
         Used internally to handle updating the component once per update interval (if update interval was provided)
